diff src/scrollbar-x.c @ 102:a145efe76779 r20-1b3

Import from CVS: tag r20-1b3
author cvs
date Mon, 13 Aug 2007 09:15:49 +0200
parents 364816949b59
children 0132846995bd
line wrap: on
line diff
--- a/src/scrollbar-x.c	Mon Aug 13 09:15:13 2007 +0200
+++ b/src/scrollbar-x.c	Mon Aug 13 09:15:49 2007 +0200
@@ -41,11 +41,11 @@
 static void x_update_horizontal_scrollbar_callback (Widget widget, LWLIB_ID id,
 						    XtPointer client_data);
 
 /* Used to prevent changing the size of the thumb while drag
    scrolling, under Motif.  This is necessary because the Motif
-   scrollbar is incredibly stupid about updating the thumb and causes
+   scrollbar is incredibly stupid about updating the slider and causes
    lots of flicker if it is done too often.  */
-static int inhibit_thumb_size_change;
+static int inhibit_slider_size_change;
 int stupid_vertical_scrollbar_drag_hack;
 
 /* Doesn't work with athena */
@@ -56,11 +56,11 @@
 
 /* A device method. */
 static int
-x_inhibit_scrollbar_thumb_size_change (void)
+x_inhibit_scrollbar_slider_size_change (void)
 {
   /* Doesn't work with Athena */
 #if defined (LWLIB_SCROLLBARS_MOTIF) || defined (LWLIB_SCROLLBARS_LUCID)
-  return inhibit_thumb_size_change;
+  return inhibit_slider_size_change;
 #else
   return 0;
 #endif
@@ -129,11 +129,11 @@
     }
 }
 
-#define UPDATE_DATA_FIELD(field)					\
-  if (new_##field >= 0 &&						\
-      SCROLLBAR_X_POS_DATA (inst).field != new_##field) {		\
-    SCROLLBAR_X_POS_DATA (inst).field = new_##field;			\
-    inst->scrollbar_instance_changed = 1;				\
+#define UPDATE_DATA_FIELD(field)				\
+  if (new_##field >= 0 &&					\
+      SCROLLBAR_X_POS_DATA (inst).field != new_##field) {	\
+    SCROLLBAR_X_POS_DATA (inst).field = new_##field;		\
+    inst->scrollbar_instance_changed = 1;			\
   }
 
 /* A device method. */
@@ -249,7 +249,7 @@
 				    struct scrollbar_instance *instance)
 {
   struct frame *f = XFRAME (w->frame);
-  char managed = XtIsManaged (SCROLLBAR_X_WIDGET (instance));
+  Boolean managed = XtIsManaged (SCROLLBAR_X_WIDGET (instance));
 
   if (active && size)
     {
@@ -591,7 +591,7 @@
 
 
     case SCROLLBAR_CHANGE:
-      inhibit_thumb_size_change = 0;
+      inhibit_slider_size_change = 0;
 #if defined (LWLIB_SCROLLBARS_MOTIF) || defined (LWLIB_SCROLLBARS_LUCID)
       vertical_drag_in_progress = 0;
       SCROLLBAR_X_VDRAG_ORIG_VALUE (instance) = data->slider_value;
@@ -606,7 +606,7 @@
       {
 	int value;
 
-	inhibit_thumb_size_change = 1;
+	inhibit_slider_size_change = 1;
 
 #if defined (LWLIB_SCROLLBARS_MOTIF) || defined (LWLIB_SCROLLBARS_LUCID)
 	/* Doing drags with Motif-like scrollbars is a mess, since we
@@ -742,10 +742,10 @@
       signal_special_Xt_user_event (win, Qscrollbar_to_right, win);
       break;
     case SCROLLBAR_CHANGE:
-      inhibit_thumb_size_change = 0;
+      inhibit_slider_size_change = 0;
       break;
     case SCROLLBAR_DRAG:
-      inhibit_thumb_size_change = 1;
+      inhibit_slider_size_change = 1;
       /* #### Fix the damn toolkit code so they all work the same way.
          Lucid is the one mostly wrong.*/
 #if defined (LWLIB_SCROLLBARS_LUCID) || defined (LWLIB_SCROLLBARS_ATHENA3D)
@@ -834,7 +834,7 @@
 void
 console_type_create_scrollbar_x (void)
 {
-  CONSOLE_HAS_METHOD (x, inhibit_scrollbar_thumb_size_change);
+  CONSOLE_HAS_METHOD (x, inhibit_scrollbar_slider_size_change);
   CONSOLE_HAS_METHOD (x, free_scrollbar_instance);
   CONSOLE_HAS_METHOD (x, release_scrollbar_instance);
   CONSOLE_HAS_METHOD (x, create_scrollbar_instance);
@@ -41,11 +41,11 @@
 						    XtPointer client_data);
 
-/* Used to prevent changing the size of the thumb while drag
+/* Used to prevent changing the size of the slider while drag
    scrolling, under Motif.  This is necessary because the Motif